@@ -18,5 +18,10 @@ if(fit$dist=="weibull")
 lambda<-fit$coefficients[length(fit$coefficients)-2:1]
 ss=lambda[1]*t^lambda[2]
 }
+if(fit$dist=="pe")
+{
+lambda<-fit$coefficients[length(fit$coefficients)-length(fit$part):1]
+ss=-ppexp(t, rate=lambda, t=fit$part, lower.tail=FALSE, log.p=TRUE)
+}
 ss
 }
